@@ -1,7 +1,7 @@
 package Getopt::Long::Subcommand;
 
-our $DATE = '2015-03-09'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-12-30'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -171,8 +171,7 @@ sub GetOptions {
             if ($ENV{COMP_LINE}) {
                 $is_completion++;
                 require Complete::Bash;
-                ($words, $cword) = @{Complete::Bash::parse_cmdline(
-                    undef,undef,'=')};
+                ($words, $cword) = @{ Complete::Bash::parse_cmdline(undef, undef, {truncate_current_word=>1}) };
             } elsif ($ENV{COMMAND_LINE}) {
                 $is_completion++;
                 require Complete::Tcsh;
@@ -251,7 +250,7 @@ Getopt::Long::Subcommand - Process command-line options, with subcommands and co
 
 =head1 VERSION
 
-This document describes version 0.03 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2015-03-09.
+This document describes version 0.04 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2015-12-30.
 
 =head1 SYNOPSIS
 
